// Copyright (c) 1995, 1996 Regents of the University of California.
// All rights reserved.
//
// This software was developed by the Arcadia project
// at the University of California, Irvine.
//
// Redistribution and use in source and binary forms are permitted
// provided that the above copyright notice and this paragraph are
// duplicated in all such forms and that any documentation,
// advertising materials, and other materials related to such
// distribution and use acknowledge that the software was developed
// by the University of California, Irvine.  The name of the
// University may not be used to endorse or promote products derived
// from this software without specific prior written permission.
// THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
// IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
// WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.

// File: ActionNudge.java
// Classes: ActionNudge
// Original Author: jrobbins@ics.uci.edu
// $Id: ActionNudge.java,v 1.4 1997/01/24 19:16:22 jrobbins Exp $

package uci.graphedit;

import java.awt.Event;

/** Action to Nudge DiagramElements from view. This command does not
 * do anything to any underlying Net or other model, it is strictly a
 * manipulation of graphical objects. Normally ActionDispose is the
 * command users will want to execute.
 *
 * @see DiagramElement
 * @see Editor
 * @see LayerDiagram */

public class ActionNudge extends Action {

   private int _direction;
  private int _magnitude;

  public static final int LEFT = 1;
  public static final int RIGHT = 2;
  public static final int UP = 3;
  public static final int DOWN = 4;

  /** Construct a new ActionNudge */
  public ActionNudge(int dir) {
    _direction = dir;
    _magnitude = 1; // Needs-More-Work: prefs
  }

  public String name() { return "Nudge DiagramElement's by a pixel"; }

  /** Move the selected items a few pixels in the given
   * direction. Note that the sign convention is the opposite of
   * ActionScroll. */
  public void doIt(Event e) {
    Editor ce = Globals.curEditor();
    Selection sel = ce.selection();
    int dx = 0, dy = 0;
    switch (_direction) {
      case LEFT: dx = 0 - _magnitude; break;
      case RIGHT: dx = _magnitude; break;
      case UP: dy = 0 - _magnitude; break;
      case DOWN: dy = _magnitude; break;
    }
    // Should I move it so that it aligns with the next grid?
    if (e.shiftDown()) { dx *= ce.gridSize(); dy *= ce.gridSize(); }
    sel.startTrans();
    sel.translate(dx, dy);
    sel.endTrans();
  }


  public void undoIt() { System.out.println("Cannot undo ActionNudge, yet."); }



} /* end class ActionNudge */
